@@ -9,8 +9,10 @@ from .utils import (sum_expansions,
                     two_two_diff)
 
 
-def signed_area(first_start: Point, first_end: Point,
-                second_start: Point, second_end: Point) -> Real:
+def signed_area(first_start: Point,
+                first_end: Point,
+                second_start: Point,
+                second_end: Point) -> Real:
     """
     Calculates signed area of parallelogram built on segments' vectors.
 
@@ -29,30 +31,26 @@ def signed_area(first_start: Point, first_end: Point,
     first_end_x, first_end_y = first_end
     second_start_x, second_start_y = second_start
     second_end_x, second_end_y = second_end
-
     minuend = ((first_end_x - first_start_x)
                * (second_end_y - second_start_y))
     subtrahend = ((first_end_y - first_start_y)
                   * (second_end_x - second_start_x))
     result = minuend - subtrahend
-
-    if minuend > 0.:
-        if subtrahend <= 0.:
+    if minuend > 0:
+        if subtrahend <= 0:
             return result
         else:
             upper_bound = minuend + subtrahend
-    elif minuend < 0.:
-        if subtrahend >= 0.:
+    elif minuend < 0:
+        if subtrahend >= 0:
             return result
         else:
             upper_bound = -minuend - subtrahend
     else:
         return result
-
     error_bound = bounds.to_signed_measure_first_error(upper_bound)
     if result >= error_bound or -result >= error_bound:
         return result
-
     return _adjusted_signed_area(first_start_x, first_start_y,
                                  first_end_x, first_end_y,
                                  second_start_x, second_start_y,
@@ -60,16 +58,19 @@ def signed_area(first_start: Point, first_end: Point,
                                  upper_bound)
 
 
-def _adjusted_signed_area(first_start_x: Real, first_start_y: Real,
-                          first_end_x: Real, first_end_y: Real,
-                          second_start_x: Real, second_start_y: Real,
-                          second_end_x: Real, second_end_y: Real,
+def _adjusted_signed_area(first_start_x: Real,
+                          first_start_y: Real,
+                          first_end_x: Real,
+                          first_end_y: Real,
+                          second_start_x: Real,
+                          second_start_y: Real,
+                          second_end_x: Real,
+                          second_end_y: Real,
                           upper_bound: Real) -> Real:
     minuend_multiplier_x = first_end_x - first_start_x
     minuend_multiplier_y = second_end_y - second_start_y
     subtrahend_multiplier_x = second_end_x - second_start_x
     subtrahend_multiplier_y = first_end_y - first_start_y
-
     minuend_tail, minuend = two_product(minuend_multiplier_x,
                                         minuend_multiplier_y)
     subtrahend_tail, subtrahend = two_product(subtrahend_multiplier_y,
@@ -81,7 +82,6 @@ def _adjusted_signed_area(first_start_x: Real, first_start_y: Real,
     error_bound = bounds.to_signed_measure_second_error(upper_bound)
     if result >= error_bound or -result >= error_bound:
         return result
-
     minuend_multiplier_x_tail = two_diff_tail(first_end_x, first_start_x,
                                               minuend_multiplier_x)
     subtrahend_multiplier_x_tail = two_diff_tail(second_end_x,
@@ -96,7 +96,6 @@ def _adjusted_signed_area(first_start_x: Real, first_start_y: Real,
             and not subtrahend_multiplier_x_tail
             and not subtrahend_multiplier_y_tail):
         return result
-
     error_bound = (bounds.to_signed_measure_third_error(upper_bound)
                    + bounds.to_determinant_error(result))
     result += ((minuend_multiplier_x * minuend_multiplier_y_tail
@@ -105,7 +104,6 @@ def _adjusted_signed_area(first_start_x: Real, first_start_y: Real,
                   + subtrahend_multiplier_x * subtrahend_multiplier_y_tail))
     if result >= error_bound or -result >= error_bound:
         return result
-
     result_expansion = sum_expansions(
             result_expansion, to_cross_product(minuend_multiplier_x_tail,
                                                minuend_multiplier_y,
