@@ -5,8 +5,10 @@ from .hints import Point
 from .utils import to_perpendicular_point
 
 
-def signed_length(first_start: Point, first_end: Point,
-                  second_start: Point, second_end: Point) -> Real:
+def signed_length(first_start: Point,
+                  first_end: Point,
+                  second_start: Point,
+                  second_end: Point) -> Real:
     """
     Calculates signed length of projection of one vector onto another.
 
